summaryrefslogtreecommitdiff
path: root/netci.groovy
diff options
context:
space:
mode:
authorwtgodbe <wigodbe@microsoft.com>2016-07-08 15:49:32 -0700
committerwtgodbe <wigodbe@microsoft.com>2016-07-08 15:51:24 -0700
commit0299f94e5742ec7bd4e1227f3667dc79126c1836 (patch)
tree571deb367705ecc89dafe42cd43ebad040aa7c14 /netci.groovy
parentfd9ab6556646fa8f02112e0cc219b792bad45433 (diff)
downloadcoreclr-0299f94e5742ec7bd4e1227f3667dc79126c1836.tar.gz
coreclr-0299f94e5742ec7bd4e1227f3667dc79126c1836.tar.bz2
coreclr-0299f94e5742ec7bd4e1227f3667dc79126c1836.zip
Add new scenario to code coverage job
Diffstat (limited to 'netci.groovy')
-rwxr-xr-xnetci.groovy23
1 files changed, 16 insertions, 7 deletions
diff --git a/netci.groovy b/netci.groovy
index 2bbd1f08c8..310fc6cca1 100755
--- a/netci.groovy
+++ b/netci.groovy
@@ -2099,15 +2099,17 @@ combinedScenarios.each { scenario ->
// Unzip the tests first. Exit with 0
shell("unzip -q -o ./clr/bin/tests/tests.zip -d ./clr/bin/tests/Windows_NT.${architecture}.${configuration} || exit 0")
- shell("ls clr/bin")
// Get corefx
shell("git clone https://github.com/dotnet/corefx fx")
- shell("ls")
- shell("pwd")
+
// Build Linux corefx
shell("./fx/build.sh x64 release Linux skiptests")
- // Check contents of bin directory - this can be removed after we confirm everything is as expected
- shell("ls ./fx/bin")
+
+ def testEnvOpt = ""
+ def scriptFileName = "\$WORKSPACE/set_stress_test_env.sh"
+ def createScriptCmds = genStressModeScriptStep(os, scenario, Constants.jitStressModeScenarios['heapverify1'], scriptFileName)
+ shell("${createScriptCmds}")
+ testEnvOpt = "--test-env=" + scriptFileName
// Run corefx tests
shell("""./fx/run-test.sh \\
@@ -2128,12 +2130,19 @@ combinedScenarios.each { scenario ->
--coreFxNativeBinDir=\"\$(pwd)/fx/bin/${osGroup}.${architecture}.Release\" \\
--crossgen --runcrossgentests""")
- // Run coreclr tests w/ server GC enabled & produce coverage reports
+ // Run coreclr tests w/ server GC & HeapVerify enabled
+ shell("""./clr/tests/runtest.sh \\
+ --testRootDir=\"\$(pwd)/clr/bin/tests/Windows_NT.${architecture}.${configuration}\" \\
+ --testNativeBinDir=\"\$(pwd)/clr/bin/obj/${osGroup}.${architecture}.${configuration}/tests\" \\
+ --coreOverlayDir=\"\$(pwd)/clr/bin/tests/Windows_NT.${architecture}.${configuration}/Tests/coreoverlay\" \\
+ --useServerGC ${testEnvOpt}""")
+
+ // Run long-running coreclr GC tests & produce coverage reports
shell("""./clr/tests/runtest.sh \\
--testRootDir=\"\$(pwd)/clr/bin/tests/Windows_NT.${architecture}.${configuration}\" \\
--testNativeBinDir=\"\$(pwd)/clr/bin/obj/${osGroup}.${architecture}.${configuration}/tests\" \\
--coreOverlayDir=\"\$(pwd)/clr/bin/tests/Windows_NT.${architecture}.${configuration}/Tests/coreoverlay\" \\
- --useServerGC --coreclr-coverage \\
+ --long-gc --playlist=\"\$(pwd)/clr/tests/longRunningGcTests.txt\" --coreclr-coverage\\
--coreclr-objs=\"\$(pwd)/clr/bin/obj/${osGroup}.${architecture}.${configuration}\" \\
--coreclr-src=\"\$(pwd)/clr/src\" \\
--coverage-output-dir=\"\${WORKSPACE}/coverage\" """)